# Copyright 2014 Hewlett-Packard Development Company, L.P.
#
# Author: Endre Karlson <endre.karlson@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import logging

from osc_lib.command import command

from designateclient import utils
from designateclient.v2.cli import common
from designateclient.v2.utils import get_all


LOG = logging.getLogger(__name__)


def _format_blacklist(blacklist):
    # Remove unneeded fields for display output formatting
    blacklist.pop('links', None)


class ListBlacklistsCommand(command.Lister):
    """List blacklists"""

    columns = ['id', 'pattern', 'description']

    def get_parser(self, prog_name):
        parser = super().get_parser(prog_name)

        common.add_all_common_options(parser)

        return parser

    def take_action(self, parsed_args):
        client = self.app.client_manager.dns
        common.set_all_common_headers(client, parsed_args)

        cols = self.columns
        data = get_all(client.blacklists.list)
        return cols, (utils.get_item_properties(s, cols) for s in data)


class ShowBlacklistCommand(command.ShowOne):
    """Show blacklist details"""

    def get_parser(self, prog_name):
        parser = super().get_parser(prog_name)

        parser.add_argument('id', help='Blacklist ID')

        common.add_all_common_options(parser)

        return parser

    def take_action(self, parsed_args):
        client = self.app.client_manager.dns
        common.set_all_common_headers(client, parsed_args)
        data = client.blacklists.get(parsed_args.id)
        _format_blacklist(data)
        return zip(*sorted(data.items()))


class CreateBlacklistCommand(command.ShowOne):
    """Create new blacklist"""

    def get_parser(self, prog_name):
        parser = super().get_parser(prog_name)

        parser.add_argument('--pattern', help='Blacklist pattern',
                            required=True)
        parser.add_argument('--description', help='Description')

        common.add_all_common_options(parser)

        return parser

    def take_action(self, parsed_args):
        client = self.app.client_manager.dns
        common.set_all_common_headers(client, parsed_args)

        data = client.blacklists.create(
            parsed_args.pattern, parsed_args.description)

        _format_blacklist(data)
        return zip(*sorted(data.items()))


class SetBlacklistCommand(command.ShowOne):
    """Set blacklist properties"""

    def get_parser(self, prog_name):
        parser = super().get_parser(prog_name)

        parser.add_argument('id', help='Blacklist ID')
        parser.add_argument('--pattern', help='Blacklist pattern')

        description_group = parser.add_mutually_exclusive_group()
        description_group.add_argument('--description', help='Description')
        description_group.add_argument('--no-description', action='store_true')

        common.add_all_common_options(parser)

        return parser

    def take_action(self, parsed_args):
        data = {}

        if parsed_args.pattern:
            data['pattern'] = parsed_args.pattern

        if parsed_args.no_description:
            data['description'] = None
        elif parsed_args.description:
            data['description'] = parsed_args.description

        client = self.app.client_manager.dns
        common.set_all_common_headers(client, parsed_args)

        updated = client.blacklists.update(parsed_args.id, data)

        _format_blacklist(updated)
        return zip(*sorted(updated.items()))


class DeleteBlacklistCommand(command.Command):
    """Delete blacklist"""

    def get_parser(self, prog_name):
        parser = super().get_parser(prog_name)

        parser.add_argument('id', help='Blacklist ID')

        common.add_all_common_options(parser)

        return parser

    def take_action(self, parsed_args):
        client = self.app.client_manager.dns
        common.set_all_common_headers(client, parsed_args)
        client.blacklists.delete(parsed_args.id)

        LOG.info('Blacklist %s was deleted', parsed_args.id)



# Copyright 2016 Hewlett Packard Enterprise Development Company LP
#
# Author: Endre Karlson <endre.karlson@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
from designateclient.tests import v2


class TestServiceStatuses(v2.APIV2TestCase, v2.CrudMixin):
    RESOURCE = 'service_statuses'

    def new_ref(self, **kwargs):
        ref = super().new_ref(**kwargs)
        ref["name"] = "foo"
        return ref

    def test_get(self):
        ref = self.new_ref()

        self.stub_entity("GET", entity=ref, id=ref["id"])

        response = self.client.service_statuses.get(ref["id"])
        self.assertEqual(ref, response)

    def test_list(self):
        items = [
            self.new_ref(),
            self.new_ref()
        ]

        self.stub_url("GET", parts=[self.RESOURCE],
                      json={"service_statuses": items})

        listed = self.client.service_statuses.list()
        self.assertList(items, listed)
        self.assertQueryStringIs("")



import logging
import os
import uuid

from keystoneauth1.identity import generic
from keystoneauth1 import session as keystone_session

from designateclient.v2 import client


logging.basicConfig(level='DEBUG')

auth = generic.Password(
    auth_url=os.environ.get('OS_AUTH_URL'),
    username=os.environ.get('OS_USERNAME'),
    password=os.environ.get('OS_PASSWORD'),
    project_name=os.environ.get('OS_PROJECT_NAME'),
    project_domain_id='default',
    user_domain_id='default')

session = keystone_session.Session(auth=auth)

client = client.Client(session=session)

# Primary Zone
primary = client.zones.create(
    f'primary-{str(uuid.uuid4())}.io.',
    'PRIMARY',
    'root@x.com')

# Secondary Zone
slave = client.zones.create(
    f'secondary-{str(uuid.uuid4())}.io.',
    'SECONDARY',
    masters=["127.0.1.1"])

# Try updating Masters for the Secondary
new_slave = client.zones.update(
    slave['id'],
    {"masters": ["10.0.0.1", "10.0.0.10"]}
)

# List all Zones
zones = client.zones.list()
